# App Settings Dictionary

![Tests](https://github.com/wheelercj/app_settings/actions/workflows/tests.yaml/badge.svg)

A dictionary-like Settings class for managing an application's settings.

Install with `pip install app-settings-dict`.  
Import with `from app_settings_dict import Settings`.

See examples of use in [the test file](https://github.com/wheelercj/app_settings/blob/master/tests/test_app_settings_dict.py) and in [zk-ssg](https://github.com/wheelercj/zk-ssg/blob/master/settings.py)'s settings file.
